SumcheckPolyBackend

Trait SumcheckPolyBackend 

pub trait SumcheckPolyBackend<P, K>: Backend
where K: Field, P: SumcheckPolyBase + ComponentPoly<K> + HasBackend<Backend = Self>,
{ // Required methods fn fix_last_variable(poly: P, alpha: K) -> P; fn sum_as_poly_in_last_variable( poly: &P, claim: Option<K>, ) -> UnivariatePolynomial<K>; }
A trait to enable backend implementations of sumcheck polynomials.

An implementation of this trait for a type will imply a crate::SumcheckPoly implementation

Required Methods

fn fix_last_variable(poly: P, alpha: K) -> P

fn sum_as_poly_in_last_variable( poly: &P, claim: Option<K>, ) -> UnivariatePolynomial<K>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<F> SumcheckPolyBackend<Mle<F>, F> for CpuBackend
where F: Field,

Implementors