ComponentPolyEvalBackend

Trait ComponentPolyEvalBackend 

pub trait ComponentPolyEvalBackend<P, K>: Backend
where P: SumcheckPolyBase + HasBackend<Backend = Self>,
{ // Required method fn get_component_poly_evals(poly: &P) -> Vec<K>; }
A trait to enable backend implementations of component polynomials.

An implementation of this trait for a type will imply a crate::ComponentPoly implementation

Required Methods

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<F, EF> ComponentPolyEvalBackend<Mle<F>, EF> for CpuBackend
where F: Field, EF: ExtensionField<F>,

Implementors