pub trait ComponentPolyEvalBackend<P, K>: Backendwhere
P: SumcheckPolyBase + HasBackend<Backend = Self>,{
// Required method
fn get_component_poly_evals(poly: &P) -> Vec<K>;
}Expand description
A trait to enable backend implementations of component polynomials.
An implementation of this trait for a type will imply a crate::ComponentPoly implementation
Required Methods
fn get_component_poly_evals(poly: &P) -> Vec<K>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.