pub trait SumCheckPolyFirstRoundBackend<P, K>: Backend{
type NextRoundPoly: SumcheckPoly<K>;
// Required methods
fn fix_t_variables(poly: P, alpha: K, t: usize) -> Self::NextRoundPoly;
fn sum_as_poly_in_last_t_variables(
poly: &P,
claim: Option<K>,
t: usize,
) -> UnivariatePolynomial<K>;
}Expand description
A trait to enable backend implementations of sumcheck polynomials for the first round.
An implementation of this trait for a type will imply a crate::SumcheckPolyFirstRound implementation for that type.
Required Associated Types
type NextRoundPoly: SumcheckPoly<K>
Required Methods
fn fix_t_variables(poly: P, alpha: K, t: usize) -> Self::NextRoundPoly
fn sum_as_poly_in_last_t_variables( poly: &P, claim: Option<K>, t: usize, ) -> UnivariatePolynomial<K>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.